Index: pkg/dartino_compiler/lib/incremental_backend.dart |
diff --git a/pkg/fletchc/lib/incremental_backend.dart b/pkg/dartino_compiler/lib/incremental_backend.dart |
similarity index 74% |
rename from pkg/fletchc/lib/incremental_backend.dart |
rename to pkg/dartino_compiler/lib/incremental_backend.dart |
index ae95e23490d4a48591d3fb71df09c0358dbe3427..ebd315d82c0200985258f31dfcb2875a101f9159 100644 |
--- a/pkg/fletchc/lib/incremental_backend.dart |
+++ b/pkg/dartino_compiler/lib/incremental_backend.dart |
@@ -2,21 +2,21 @@ |
// for details. All rights reserved. Use of this source code is governed by a |
// BSD-style license that can be found in the LICENSE.md file. |
-library fletchc.incremental_backend; |
+library dartino_compiler.incremental_backend; |
import 'package:compiler/src/elements/elements.dart' show |
Element, |
FieldElement, |
FunctionElement; |
-import 'fletch_system.dart' show |
- FletchSystem; |
+import 'dartino_system.dart' show |
+ DartinoSystem; |
-import 'src/fletch_system_builder.dart' show |
- FletchSystemBuilder; |
+import 'src/dartino_system_builder.dart' show |
+ DartinoSystemBuilder; |
-import 'src/fletch_context.dart' show |
- FletchContext; |
+import 'src/dartino_context.dart' show |
+ DartinoContext; |
// TODO(ahe): Move this to dart2js upstream when it's stabilized |
abstract class IncrementalBackend { |
@@ -44,16 +44,16 @@ abstract class IncrementalBackend { |
/// Update references to [element] in [users]. |
// TODO(ahe): Computing [users] is expensive, and may not be necessary in |
// dart2js. Move to IncrementalFletchBackend or add a bool to say if the call |
// is needed. |
void replaceFunctionUsageElement(Element element, List<Element> users); |
} |
-abstract class IncrementalFletchBackend implements IncrementalBackend { |
- FletchSystemBuilder get systemBuilder; |
+abstract class IncrementalDartinoBackend implements IncrementalBackend { |
+ DartinoSystemBuilder get systemBuilder; |
- void newSystemBuilder(FletchSystem predecessorSystem); |
+ void newSystemBuilder(DartinoSystem predecessorSystem); |
- /// In Fletch, assembleProgram is incremental. In dart2js it isn't. |
+ /// In Dartino, assembleProgram is incremental. In dart2js it isn't. |
int assembleProgram(); |
} |
@@ -44,16 +44,16 @@ abstract class IncrementalBackend { |
/// Update references to [element] in [users]. |
// TODO(ahe): Computing [users] is expensive, and may not be necessary in |
- // dart2js. Move to IncrementalFletchBackend or add a bool to say if the call |
+ // dart2js. Move to IncrementalDartinoBackend or add a bool to say if the call |
// is needed. |
void replaceFunctionUsageElement(Element element, List<Element> users); |